import argparse
import os

from .gief import __doc__, app


parser = argparse.ArgumentParser(prog='gief', description=__doc__)

parser.add_argument('path', nargs='?', default=os.getcwd(),
                    help='Folder where files will be uploaded to (CWD by default)')
parser.add_argument('-H', '--host', default='0.0.0.0')
parser.add_argument('-p', '--port', type=int, default=5000)

args = parser.parse_args()
app.config['path'] = args.path
app.run(args.host, args.port)



import os
from flask import Flask, request, redirect, url_for
from werkzeug import secure_filename


app = Flask(__name__)

@app.route('/', methods=['GET'])
def get():
    return '''
    <!doctype html>
    <title>Gimme</title>
    <h1>Gimme</h1>
    <form action="" method=post enctype=multipart/form-data>
      <p><input type=file name=file>
         <input type=submit value=Upload>
    </form>
    '''

@app.route('/', methods=['POST'])
def post():
    file = request.files['file']
    filename = secure_filename(file.filename)
    file.save(os.path.join(app.config['path'], filename))
    return filename + ' uploaded'



from setuptools import setup

import gief


setup(
  name = 'gief',
  description = gief.__doc__,
  version = gief.__version__,
  packages = ['gief'],
  scripts = ['scripts/gief'],
  install_requires = ['flask', 'werkzeug'],
  url = 'https://github.com/jorgebg/gief',
  author = gief.__author__,
  author_email = gief.__author_email__,
  license = gief.__license__,
  keywords = ['http', 'upload', 'server', 'file']
)
